pub fn format_bytes(source: &[u8]) -> FormatOutputExpand description
Decodes and formats Stack source bytes into the canonical UTF-8 representation.
pub fn format_bytes(source: &[u8]) -> FormatOutputDecodes and formats Stack source bytes into the canonical UTF-8 representation.